.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents

   installation
   usage
   shallow-water
   sharp-bits
   api

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
